EXPORTS
	?ChangeStyleL@TFormAndEtextEditor@@UAEHABVRTmStyle@@@Z @ 1 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::ChangeStyleL(class RTmStyle const &)
	?CopyToStoreL@TFormAndEtextEditor@@UBEXAAVCStreamStore@@AAVCStreamDictionary@@HH@Z @ 2 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::CopyToStoreL(class CStreamStore &,class CStreamDictionary &,int,int)const 
	?CreateStyleL@TFormAndEtextEditor@@UAEHABVRTmStyle@@@Z @ 3 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::CreateStyleL(class RTmStyle const &)
	?DeleteCharFormatL@TFormAndEtextEditor@@UAEXHH@Z @ 4 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::DeleteCharFormatL(int,int)
	?DeleteParFormatL@TFormAndEtextEditor@@UAEXHH@Z @ 5 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::DeleteParFormatL(int,int)
	?DeleteStyleL@TFormAndEtextEditor@@UAEHABVTDesC16@@@Z @ 6 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::DeleteStyleL(class TDesC16 const &)
	?DeleteTextL@TFormAndEtextEditor@@UAEXHH@Z @ 7 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::DeleteTextL(int,int)
	?DocumentLength@TFormAndEtextEditor@@UBEHXZ @ 8 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::DocumentLength(void)const 
	?GetBaseFormatL@TFormAndEtextEditor@@UBEXAAVTTmCharFormat@@AAVRTmParFormat@@@Z @ 9 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::GetBaseFormatL(class TTmCharFormat &,class RTmParFormat &)const 
	?GetCharFormat@TFormAndEtextEditor@@UBEXHW4TFormatLevel@MUnifiedEditor@@AAVTTmCharFormatLayer@@AAH@Z @ 10 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::GetCharFormat(int,enum MUnifiedEditor::TFormatLevel,class TTmCharFormatLayer &,int &)const 
	?GetParFormatL@TFormAndEtextEditor@@UBEXHW4TFormatLevel@MUnifiedEditor@@AAVRTmParFormatLayer@@AAH@Z @ 11 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::GetParFormatL(int,enum MUnifiedEditor::TFormatLevel,class RTmParFormatLayer &,int &)const 
	?GetStyle@TFormAndEtextEditor@@UBEXHAAVTPtrC16@@AAH@Z @ 12 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::GetStyle(int,class TPtrC16 &,int &)const 
	?GetStyleByIndexL@TFormAndEtextEditor@@UBEHHAAVRTmStyle@@@Z @ 13 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::GetStyleByIndexL(int,class RTmStyle &)const 
	?GetStyleByNameL@TFormAndEtextEditor@@UBEHABVTDesC16@@AAVRTmStyle@@@Z @ 14 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::GetStyleByNameL(class TDesC16 const &,class RTmStyle &)const 
	?GetText@TFormAndEtextEditor@@UBEXHAAVTPtrC16@@@Z @ 15 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::GetText(int,class TPtrC16 &)const 
	?InsertTextL@TFormAndEtextEditor@@UAEXHABVTDesC16@@PBV2@PBVTTmCharFormatLayer@@PBVRTmParFormatLayer@@@Z @ 16 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::InsertTextL(int,class TDesC16 const &,class TDesC16 const *,class TTmCharFormatLayer const *,class RTmParFormatLayer const *)
	?Interface@TFormAndEtextEditor@@UAEPAVMTmOptionalInterface@@I@Z @ 17 NONAME ; public: virtual class MTmOptionalInterface * __thiscall TFormAndEtextEditor::Interface(unsigned int)
	?PasteFromStoreL@TFormAndEtextEditor@@UAEXABVCStreamStore@@ABVCStreamDictionary@@H@Z @ 18 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::PasteFromStoreL(class CStreamStore const &,class CStreamDictionary const &,int)
	?RenameStyleL@TFormAndEtextEditor@@UAEHABVTDesC16@@0@Z @ 19 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::RenameStyleL(class TDesC16 const &,class TDesC16 const &)
	?SetBaseFormatL@TFormAndEtextEditor@@UAEXABVTTmCharFormat@@ABVRTmParFormat@@@Z @ 20 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::SetBaseFormatL(class TTmCharFormat const &,class RTmParFormat const &)
	?SetCharFormatL@TFormAndEtextEditor@@UAEXHHABVTTmCharFormatLayer@@@Z @ 21 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::SetCharFormatL(int,int,class TTmCharFormatLayer const &)
	?SetParFormatL@TFormAndEtextEditor@@UAEXHHABVRTmParFormatLayer@@@Z @ 22 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::SetParFormatL(int,int,class RTmParFormatLayer const &)
	?SetStyleL@TFormAndEtextEditor@@UAEHHHABVTDesC16@@@Z @ 23 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::SetStyleL(int,int,class TDesC16 const &)
	?StyleCount@TFormAndEtextEditor@@UBEHXZ @ 24 NONAME ; public: virtual int __thiscall TFormAndEtextEditor::StyleCount(void)const 
	?DropPictureL@TFormAndEtextEditor@@UAEXH@Z @ 25 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::DropPictureL(int)
	?InsertPictureL@TFormAndEtextEditor@@UAEXHABVTPictureHeader@@@Z @ 26 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::InsertPictureL(int,class TPictureHeader const &)
	?Picture@TFormAndEtextEditor@@UBEXHAAVTPictureHeader@@@Z @ 27 NONAME ; public: virtual void __thiscall TFormAndEtextEditor::Picture(int,class TPictureHeader &)const 

